0.3 (2016-02-05)
----------------

- Add filter response curves and filters module.
- Add pyyaml required dependency (for reading filter curves).

0.2 (2015-11-15)
----------------

- Add downsample module.

0.1 (2015-08-05)
----------------

- Initial release.
